@@ -2,7 +2,7 @@
 #     Project: PyZendesk
 # Description: API for Zendesk
 #      Author: Fabio Castelli (Muflone) <muflone@muflone.com>
-#   Copyright: 2021 Fabio Castelli
+#   Copyright: 2021-2022 Fabio Castelli
 #     License: GPL-3+
 #  This program is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -94,6 +94,16 @@ class Api(object):
                                json=json)
         return req.json()
 
+    def request_delete(self,
+                       path: str) -> dict:
+        """
+        Send a DELETE REST request to Zendesk
+
+        :param path: API path which will be added to the base API path
+        :return: response from JSON data
+        """
+        return self.request(method='delete', path=path, json=None)
+
     def request_get(self,
                     path: str) -> dict:
         """
@@ -104,6 +114,18 @@ class Api(object):
         """
         return self.request(method='get', path=path, json=None)
 
+    def request_post(self,
+                     path: str,
+                     json: dict) -> dict:
+        """
+        Send a POST REST request to Zendesk
+
+        :param path: API path which will be added to the base API path
+        :param json: additional JSON data to send along with the request
+        :return: response from JSON data
+        """
+        return self.request(method='post', path=path, json=json)
+
     def request_put(self,
                     path: str,
                     json: dict) -> dict:
