@@ -2,7 +2,7 @@
 #     Project: PyZendesk
 # Description: API for Zendesk
 #      Author: Fabio Castelli (Muflone) <muflone@muflone.com>
-#   Copyright: 2021 Fabio Castelli
+#   Copyright: 2021-2022 Fabio Castelli
 #     License: GPL-3+
 #  This program is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -19,10 +19,10 @@
 ##
 
 APP_NAME = 'PyZendesk'
-APP_VERSION = '0.2.1'
+APP_VERSION = '0.4.0'
 APP_DESCRIPTION = 'API for Zendesk'
 APP_ID = 'pyzendesk.muflone.com'
-APP_URL = 'http://www.muflone.com/pyzendesk/'
+APP_URL = 'https://www.muflone.com/pyzendesk/'
 APP_AUTHOR = 'Fabio Castelli'
 APP_AUTHOR_EMAIL = 'muflone@muflone.com'
-APP_COPYRIGHT = 'Copyright 2021 %s' % APP_AUTHOR
+APP_COPYRIGHT = 'Copyright 2021-2022 %s' % APP_AUTHOR
